pub struct PromoteArgs {
pub doc: PathBuf,
pub candidate: String,
pub into: String,
pub id_suffix: String,
}Expand description
Arguments for zenith workspace promote.
Fields
doc: PathBufPath to the deliverable .zen document (written in-place).
candidate: StringThe candidate id to promote (must have status selected).
into: StringId of the target page in the deliverable document to merge content into.
id_suffix: StringSuffix appended to every cloned node id to keep them unique (default: .promoted).