run

Function run 

pub fn run(src: &str) -> Result<FmtResult, FmtErr>
Parse src, format it canonically, and return the result.

Returns Err(FmtErr) on parse or format failure. On success returns FmtResult with the formatted bytes, a changed flag, and a content hash.