marker_dir

Function marker_dir 

pub fn marker_dir(
    agent: Agent,
    scope: Scope,
    project_root: &Path,
) -> Option<PathBuf>
The directory whose existence signals that agent is in use, for a scope. Detection markers are intentionally the agent’s config dir, which may differ from where the skill is written.