pub fn sync_external(doc_path: &Path) -> Result<SyncOutcome, String>Expand description
Capture the current on-disk content of doc_path into Tier-1 history as an
external change, if it differs from the session HEAD. Resolves the real data dir.
pub fn sync_external(doc_path: &Path) -> Result<SyncOutcome, String>Capture the current on-disk content of doc_path into Tier-1 history as an
external change, if it differs from the session HEAD. Resolves the real data dir.