pub fn undo_edit(doc_path: &Path) -> Result<NavOutcome, String>Expand description
Undo the last edit for the document at doc_path, rewriting the file in place.
Resolves the real data directory automatically. Use undo_edit_in in tests.
pub fn undo_edit(doc_path: &Path) -> Result<NavOutcome, String>Undo the last edit for the document at doc_path, rewriting the file in place.
Resolves the real data directory automatically. Use undo_edit_in in tests.