Module json_types

Module json_types 

Serialisable DTO types for JSON output.

These types are defined in the CLI crate — we do NOT add serde to zenith-core. Each type maps from zenith-core/zenith-scene types to a schema-versioned JSON shape.

Structs

DiagnosticJson
JSON representation of a zenith_core::Diagnostic.
FmtOutput
Top-level JSON envelope for fmt.
FontsOutput
Top-level JSON envelope for zenith fonts --json.
ManifestRow
One row entry in the generation manifest (successful rows only).
MergeManifest
Deterministic generation manifest for zenith merge --manifest.
MergeOutput
Top-level JSON envelope for merge --json.
MergeRowResult
Per-row result in the merge --json batch report.
RecipeInspectJson
A single recipe entry in the recipes array of crate::commands::inspect::InspectOutput.
RecipeParamInspectJson
A single param entry within a RecipeInspectJson.
RenderOutput
Top-level JSON envelope for render.
SchemaAttr
A single attribute entry in the schema node <kind> and schema page/asset/document JSON output.
SchemaBrandChildNode
One child-node descriptor in the schema brand JSON output.
SchemaBrandDiagCode
One diagnostic code entry in the schema brand JSON output.
SchemaBrandOutput
Top-level JSON envelope for schema brand.
SchemaDiagnosticCode
A single governable diagnostic-code entry in the schema diagnostics JSON.
SchemaDiagnosticsOutput
Top-level JSON envelope for schema diagnostics.
SchemaNodeContent
Child-content descriptor embedded in SchemaNodeDetail.
SchemaNodeDetail
A single node-kind detail entry in the schema node <kind> JSON output.
SchemaNodeEntry
A single node-kind entry in the schema nodes JSON output.
SchemaNodeOutput
Top-level JSON envelope for schema node <kind>.
SchemaNodesOutput
Top-level JSON envelope for schema nodes.
SchemaOpDetail
Full detail entry in the schema op <name> JSON output.
SchemaOpEntry
A single op entry in the schema ops JSON output.
SchemaOpFieldEntry
A single op field entry in the schema op <name> JSON output.
SchemaOpOutput
Top-level JSON envelope for schema op <name>.
SchemaOpsOutput
Top-level JSON envelope for schema ops.
SchemaOverridePropEntry
One override property entry in the schema variant JSON output.
SchemaOverviewOutput
Top-level JSON envelope for bare zenith schema (overview).
SchemaSurfaceOutput
Top-level JSON envelope for schema page, schema asset, schema document.
SchemaTokenDetail
Full detail for one token type in the schema token <type> JSON output.
SchemaTokenEntry
A single token-type entry in the schema tokens JSON output.
SchemaTokenOutput
Top-level JSON envelope for schema token <type>.
SchemaTokensOutput
Top-level JSON envelope for schema tokens.
SchemaVariantOutput
Top-level JSON envelope for schema variant.
TokenEntry
A single token entry for tokens output.
TokensOutput
Top-level JSON envelope for tokens.
TxOutputJson
Top-level JSON envelope for tx.
ValidateOutput
Top-level JSON envelope for validate.
VariantManifest
Deterministic generation manifest for zenith variant --manifest.
VariantManifestTarget
One target entry in the variant generation manifest (successful variants only).
VariantOutput
Top-level JSON envelope for variant --json.
VariantResultJson
Per-variant result in the variant --json envelope.