pub fn run(
src: &str,
node_id: Option<&str>,
json: bool,
) -> Result<String, InspectCmdErr>Expand description
Run zenith inspect.
src— raw.zensource text.node_id— whenSome, restrict output to the subtree rooted at that id.json— emit JSON instead of the human-readable tree.
Returns a formatted string on success, or an InspectCmdErr on parse
error, not-found error, etc.